@@ -48,3 +48,7 @@ class TestDemoDryRuns:
     def test_cmd_exe(self):
         result = shell(f"cd {DEMO_DIR}/cmd.exe && {CMD_SEQ}")
         assert result.exit_code == 0
+
+    def test_nextflow(self):
+        result = shell(f"cd {DEMO_DIR}/nextflow && {CMD_SEQ}")
+        assert result.exit_code == 0
